@@ -102,7 +102,7 @@ def task__format() -> DoitTask:
         f'{run_mod()} black {paths} --quiet',
         f'{run_mod()} pyupgrade {file_paths} --py310-plus --keep-runtime-typing --exit-zero',
         f'{run_mod()} unimport {paths} --include-star-import --remove',
-        f'{run_mod()} absolufy-imports {file_paths} --never',
+        f'{smart_exec("absolufy-imports")} {file_paths} --never',
         f'{run_mod()} isort {paths}',
         f'{run_mod()} docformatter {file_paths} {docfmt_args}',
     ])
@@ -132,7 +132,7 @@ def task__test() -> DoitTask:
         DoitTask: doit task
 
     """
-    return user_task([
+    return debug_task([
         Interactive(f'{run_mod()} pytest tests {SETTINGS.ARGS_PYTEST}'),
     ])
 
@@ -167,11 +167,12 @@ def _merge_linting_logs(flake8_log_path: Path, pylint_log_path: Path) -> bool:
     flake8_logs = flake8_log_path.read_text().strip()
     pylint_logs = pylint_log_path.read_text().strip()
     if flake8_logs or pylint_logs:
-        no_errors = False
         flake8_parsed = parse_flake8_logs(flake8_logs)
         pylint_parsed = parse_pylint_json_logs(pylint_logs)
-        console = Console()
-        display_lint_logs(console, flake8_parsed + pylint_parsed)
+        if parsed_errors := flake8_parsed + pylint_parsed:
+            no_errors = False
+            console = Console()
+            display_lint_logs(console, parsed_errors)
 
     if_found_unlink(flake8_log_path)
     if_found_unlink(pylint_log_path)
